searchData={"items":[{"type":"module","title":"BitrixEx","doc":"HTTP client make using Tesla for integrating with the Bitrix24 API","ref":"BitrixEx.html"},{"type":"function","title":"BitrixEx.application_url/0","doc":"","ref":"BitrixEx.html#application_url/0"},{"type":"function","title":"BitrixEx.authenticate/2","doc":"authenticate application add get access token","ref":"BitrixEx.html#authenticate/2"},{"type":"function","title":"BitrixEx.authorization_url/1","doc":"Generate authorization url","ref":"BitrixEx.html#authorization_url/1"},{"type":"function","title":"Examples - BitrixEx.authorization_url/1","doc":"iex> BitrixEx.authorization_url()\n    \"https://mydomain.bitrix24.com/oauth/authorize/?client_id=app.xxxxxxxxxxxxxx.xxxxxxxx&response_type=code\"\n\nadditionally you can add a redirect uri\n\n    iex> redirect_uri = \"https://mydomain.com/callback\"\n    iex> BitrixEx.authorization_url(redirect_uri)\n    \"https://mydomain.bitrix24.com/oauth/authorize/?client_id=app.xxxxxxxxxxxxxx.xxxxxxxx&redirect_uri=https%3A%2F%2Fmydomain.com%2Fcallback&response_type=code\"","ref":"BitrixEx.html#authorization_url/1-examples"},{"type":"function","title":"BitrixEx.call_method/1","doc":"Call method using a webhook url\n\n    config :bitrix_ex,\n      webhook_url: \"https://mydomain.bitrix24.com/rest/1/xxxx\"","ref":"BitrixEx.html#call_method/1"},{"type":"function","title":"Examples - BitrixEx.call_method/1","doc":"iex> BitrixEx.call_method(\"tasks.task.list\")\n    {:ok, %{\"result\" => %{\"tasks\" => []}}}","ref":"BitrixEx.html#call_method/1-examples"},{"type":"function","title":"BitrixEx.call_method/2","doc":"Call method using a webhook url","ref":"BitrixEx.html#call_method/2"},{"type":"function","title":"Examples - BitrixEx.call_method/2","doc":"config :bitrix_ex,\n      webhook_url: \"https://mydomain.bitrix24.com/rest/1/xxxx\"\n\n    iex> method = \"tasks.task.list\"\n    iex> params = %{select: [\"ID\", \"TITLE\"], filter: %{\"GROUP_ID\" => 1}}\n    iex> BitrixEx.call_method(method, params)\n    {:ok,\n      %{\n        \"result\" => %{\n          \"tasks\" => [\n            %{\"id\" => 1, \"title\" => \"test\"},\n            %{\"id\" => 2, \"title\" => \"test2\"}\n          ]\n        }\n      }\n    }\n\nCall method using a local or standard application","ref":"BitrixEx.html#call_method/2-examples"},{"type":"function","title":"Examples - BitrixEx.call_method/2","doc":"config :bitrix_ex,\n      application_url: \"https://mydomain.bitrix24.com/rest/\",\n      # or just \"https://mydomain.bitrix24.com\"\n\nfor this call the access token must be passed in the params\n\n    iex> access_token = \"your_access_token\"\n    iex> BitrixEx.call_method(\"tasks.task.list\", %{auth: access_token})\n    {:ok, %{\"result\" => %{\"tasks\" => []}}}","ref":"BitrixEx.html#call_method/2-examples"},{"type":"function","title":"BitrixEx.call_method/3","doc":"Similar to the previous ones, but it has the additional parameter `opts`\nfor using Tesla resources.","ref":"BitrixEx.html#call_method/3"},{"type":"function","title":"BitrixEx.client_id/0","doc":"","ref":"BitrixEx.html#client_id/0"},{"type":"function","title":"BitrixEx.client_secret/0","doc":"","ref":"BitrixEx.html#client_secret/0"},{"type":"function","title":"BitrixEx.oauth_url/0","doc":"","ref":"BitrixEx.html#oauth_url/0"},{"type":"function","title":"BitrixEx.refresh_token/2","doc":"use refresh token to get a new access token","ref":"BitrixEx.html#refresh_token/2"},{"type":"function","title":"BitrixEx.webhook_url/0","doc":"","ref":"BitrixEx.html#webhook_url/0"},{"type":"extras","title":"BitrixEx","doc":"# BitrixEx\n\nHTTP client make using Tesla for integrating with the Bitrix24 API\n\nThis client provides functions to interact with the Bitrix24 API, including methods for making API calls using webhooks or local/standard applications, user authentication, and token management.","ref":"readme.html"},{"type":"extras","title":"Installation - BitrixEx","doc":"To use the BitrixEx module, you need to add it to your project's dependencies\nand configure it in your application's configuration.\n\n```elixir\ndef deps do\n  [\n    {:bitrix_ex, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Obtaining access credentials - BitrixEx","doc":"In your Bitrix24 account, register a new local application.\n\nDuring the authentication process, the Bitrix server will make a GET request to your application containing the authorization code in the query parameters.\n\nDefine an endpoint that your application will use to handle the Bitrix server call.\n\nAfter registering your application, Bitrix will generate your application ID (client_id) and your secret key (client_secret).\n\nSomething like: `http://localhost:4000/callback`.\n\nYou can use the `BitrixEx.authorization_url/0` function to get your authorization URL.\n\nIn a browser, use the authorization URL. The Bitrix server will redirect the call to your application endpoint.\n\nYou will receive an authorization token with 30 seconds validity in the query parameters.\n\nAfter obtaining your authorization token (client_code), use the `BitrixEx.authenticate/1` function to obtain your access token.\n\nThe access token will be used in requests that do not use the webhook.","ref":"readme.html#obtaining-access-credentials"},{"type":"extras","title":"BitrixEx Configuration - BitrixEx","doc":"Before using the module, you need to configure the Bitrix24 API settings\nin your application's configuration. This includes specifying the domain,\nwebhook URL, application URL, client ID, client secret, and OAuth URL.\nYou can set these values in your application's configuration file or\nthrough environment variables.\n\nExample configuration:\n\n```elixir\n# config/config.exs\nconfig :bitrix_ex,\n  webhook_url: System.get_env(\"BITRIX_WEBHOOK_URL\"),\n  application_url: System.get_env(\"BITRIX_APPLICATION_URL\"),\n  client_id: System.get_env(\"BITRIX_CLIENT_ID\"),\n  client_secret: System.get_env(\"BITRIX_CLIENT_SECRET\"),\n  oauth_url: System.get_env(\"BITRIX_OAUTH_URL\")\n\n# config :bitrix_ex,\n#   webhook_url: \"https://mydomain.bitrix24.com/rest/1/xxxx\",\n#   application_url: \"https://mydomain.bitrix24.com/rest/\", # or just \"https://mydomain.bitrix24.com\"\n#   client_id: \"app.xxxxxxxxxxxxxx.xxxxxxxx\",\n#   client_secret: \"xxXXxxxxxxXXXxXxXxXXXxXxxxXxXXXxxxxXXxXXxxXxxXxxxx\",\n#   oauth_url: \"https://oauth.bitrix.info/oauth/token/\"\n```","ref":"readme.html#bitrixex-configuration"},{"type":"extras","title":"Usage - BitrixEx","doc":"#","ref":"readme.html#usage"},{"type":"extras","title":"Call method using a webhook url - BitrixEx","doc":"Necessary configuration\n\n```elixir\n# config/config.exs\nconfig :bitrix_ex,\n  webhook_url: \"https://mydomain.bitrix24.com/rest/1/xxxx\"\n```\n\n```elixir\niex> BitrixEx.call_method(\"tasks.task.list\")\n{:ok, %{\"result\" => %{\"tasks\" => [...]}}}\n```\n\nPassing additional parameters\n\n```elixir\niex> method = \"tasks.task.list\"\niex> params = %{select: [\"ID\", \"TITLE\"], filter: %{\"GROUP_ID\" => 1}}\niex> BitrixEx.call_method(method, params)\n{:ok,\n  %{\n    \"result\" => %{\n      \"tasks\" => [\n        %{\"id\" => 1, \"title\" => \"test\"},\n        %{\"id\" => 2, \"title\" => \"test2\"}\n      ]\n    }\n  }\n}\n```\n\n#","ref":"readme.html#call-method-using-a-webhook-url"},{"type":"extras","title":"Call method using a standard application url - BitrixEx","doc":"Necessary configuration\n\n```elixir\n# config/config.exs\nconfig :bitrix_ex,\n  application_url: \"https://mydomain.bitrix24.com/rest/\"\n  # or just \"https://mydomain.bitrix24.com\"\n```\n\nFor this call the access token must be passed in the params\n\n```elixir\niex> access_token = \"your_access_token\"\niex> BitrixEx.call_method(\"tasks.task.list\", %{auth: access_token})\n{:ok, %{\"result\" => %{\"tasks\" => [...]}}}\n```\n\nPassing additional parameters\n\n```elixir\niex> method = \"tasks.task.list\"\niex> access_token = \"your_access_token\"\niex> params = %{auth: access_token, select: [\"ID\", \"NAME\"], filter: %{\"GROUP_ID\" => 1}}\niex> BitrixEx.call_method(method, params)\n{:ok, %{\"result\" => %{\"tasks\" => [...]}}}\n```\n\n#","ref":"readme.html#call-method-using-a-standard-application-url"},{"type":"extras","title":"Generate authorization url - BitrixEx","doc":"- The authorization url can be used to get the authorization code.\n- The authorization code can be exchanged for an access token.\n- The access token can be used to make API calls.\n- The authorization code expires after 30 seconds.\n\nNecessary configuration\n\n```elixir\n# config/config.exs\nconfig :bitrix_ex,\n  application_url: \"https://mydomain.bitrix24.com/rest/\",\n  client_id: \"app.xxxxxxxxxxxxxx.xxxxxxxx\"\n```\n\n```elixir\niex> redirect_uri = \"https://mydomain.com/callback\"\niex> BitrixEx.authorization_url(redirect_uri)\n\"https://mydomain.bitrix24.com/oauth/authorize/?client_id=app.xxxxxxxxxxxxxx.xxxxxxxx&response_type=code\"\n```\n\nPassing a optional redirect uri\n\n```elixir\niex> redirect_uri = \"https://mydomain.com/callback\"\niex> BitrixEx.authorization_url(redirect_uri)\n\"https://mydomain.bitrix24.com/oauth/authorize/?client_id=app.xxxxxxxxxxxxxx.xxxxxxxx&redirect_uri=https%3A%2F%2Fmydomain.com%2Fcallback&response_type=code\"\n```\n\n#","ref":"readme.html#generate-authorization-url"},{"type":"extras","title":"authenticate application and get access token - BitrixEx","doc":"Necessary configuration\n\n```elixir\nconfig :bitrix_ex,\n  oauth_url: \"https://oauth.bitrix.info/oauth/token/\",\n  client_id: \"app.xxxxxxxxxxxxxx.xxxxxxxx\",\n  client_secret: \"xxXXxxxxxxXXXxXxXxXXXxXxxxXxXXXxxxxXXxXXxxXxxXxxxx\"\n```\n\nFor this call the authorization code must be passed in the params\n\n```elixir\niex> authorization_code = \"your_authorization_code\"\niex> BitrixEx.authenticate(authorization_code)\n{:ok,\n  %{\n    \"access_token\" => \"your_access_token\",\n    \"expires_in\" => 3600,\n    \"refresh_token\" => \"your_refresh_token\"\n  }\n}\n```\n\n#","ref":"readme.html#authenticate-application-and-get-access-token"},{"type":"extras","title":"Refreshing access token - BitrixEx","doc":"Necessary configuration\n\n```elixir\nconfig :bitrix_ex,\n  oauth_url: \"https://oauth.bitrix.info/oauth/token/\",\n  client_id: \"app.xxxxxxxxxxxxxx.xxxxxxxx\",\n  client_secret: \"xxXXxxxxxxXXXxXxXxXXXxXxxxXxXXXxxxxXXxXXxxXxxXxxxx\"\n```\n\nFor this call the refresh token must be passed in the params\n\n```elixir\niex> refresh_token = \"your_refresh_token\"\niex> BitrixEx.refresh_token(refresh_token)\n{:ok,\n  %{\n    \"access_token\" => \"your_access_token\",\n    \"expires_in\" => 3600,\n    \"refresh_token\" => \"your_refresh_token\"\n  }\n}\n```","ref":"readme.html#refreshing-access-token"},{"type":"extras","title":"Notes - BitrixEx","doc":"Bitrix supports the following comparison operations:\n\n- \"=\" - equal\n- \"!\" - not equal\n- \"<\" - less\n- \"<=\" - less or equal\n- \">\" - more\n- \">=\" - more or equal\n\n```elixir\n%{filter: %{\"GROUP_ID\" => 1}} # group_id = 1\n%{filter: %{\"=GROUP_ID\" => 1}} # group_id = 1\n%{filter: %{\"!=GROUP_ID\" => 1}} # group_id != 1\n%{filter: %{\" GROUP_ID\" => 1}} # group_id > 1\n%{filter: %{\">=GROUP_ID\" => 1}} # group_id >= 1\n```\n\nEach method in Bitrix has its own behavior. For example, a \"list\" method can bring different fields from a \"get\" method.\n\nSometimes one method brings you a Json result with camelCase fields while another brings you one with UPPERCASE.\n\nIn some \"get\" methods you can pass the parameters `%{id: 1}` simply and in other cases `%{ID: 1}` or `%{params: %{id: 1}}`\n\nIn some \"list\" methods you can filter boolean fields as `true` or `false` and in others it will be `\"Y\"` or `\"N\"`\n\n```elixir\n%{filter: %{\"ACTIVE\" => true}}\n%{filter: %{\"ACTIVE\" => \"Y\"}}\n%{filter: %{\"ACTIVE\" => false}}\n%{filter: %{\"ACTIVE\" => \"N\"}}\n```\n\nLikewise, not all methods support all of the Boolean filters listed above.\n\nIt is very important that you evaluate each case and develop ways to normalize the data.\n\nVocê pode ver os métodos disponíveis da documentação da API\n\n[Bitrix24 REST API (Documentation)](https://training.bitrix24.com/rest_help/index.php)","ref":"readme.html#notes"}],"content_type":"text/markdown"}